@@ -10,7 +10,12 @@ def test_gaussian_fit():
     np.testing.assert_almost_equal(
         np.nanmax(my_binary.PkHt_ch0.values), 98708.92915295, decimal=1)
     np.testing.assert_almost_equal(
-        np.nanmax(my_binary.PkHt_ch4.values), 54734.05714286, decimal=1)
+        np.nanmax(my_binary.PkHt_ch4.values), 65088.3959945008, decimal=1)
+    # check that there are requal amounts of successful fits for low gain and
+    # high gain scattering when the peak heighs are large enough
+    bl_hg = np.logical_and(my_binary['FtAmp_ch0'] > 30000,
+                           my_binary['FtAmp_ch0'] < 50000)
+    assert np.sum(bl_hg) == np.isfinite(my_binary['FtAmp_ch4'][bl_hg]).sum()
 
 
 def test_psds():
